@@ -28,7 +28,7 @@
 #include <kapplication.h>
 #include <kdebug.h>
 #include <kbuttonbox.h>
-#include <kcolordlg.h>
+#include <kcolordialog.h>
 #include <kconfig.h>
 #include <kglobal.h>
 #include <klocale.h>
@@ -41,6 +41,7 @@
 
 #include "matrix.h"
 #include <qpainter.h>
+#include <qimage.h>
 
 
 // libkscreensaver interface
@@ -73,10 +74,6 @@ void KMatrixSaverCfg::readSettings() {
   KConfig *config = KGlobal::config();
   config->setGroup("Settings");
 
-  background = config->readColorEntry("BackgroundColor", &Qt::black);
-  foreground = config->readColorEntry("ForegroundColor", &Qt::green);
-  //str = config->readEntry("Mono");
-  mono = false;
   density = config->readNumEntry("Density", 25);
   speed = config->readNumEntry("Speed", 100);
   insert = config->readEntry("Insert", "bottom");
@@ -86,9 +83,6 @@ void KMatrixSaverCfg::writeSettings() {
   KConfig *config = KGlobal::config();
   config->setGroup( "Settings" );
 
-  config->writeEntry("BackgroundColor", background);
-  config->writeEntry("ForegroundColor", foreground);
-  //config->writeEntry("Mono", str);
   config->writeEntry("Density", density);
   config->writeEntry("Speed", speed);
   config->writeEntry("Insert", insert);
@@ -103,7 +97,6 @@ KMatrixSaver::KMatrixSaver( WId id ) : KScreenSaver( id ) {
   rnd = new KRandomSequence();
   readSettings();
 
-  blank();
   init_matrix();
   timer.start(cfg.speed);
   connect(&timer, SIGNAL(timeout()), SLOT(slotTimeout()));
@@ -123,16 +116,6 @@ KMatrixSaver::~KMatrixSaver() {
 
 //--------------------------------------------------------------------
 // configuration API
-void KMatrixSaver::setBackgroundColor( const QColor &col ) {
-  cfg.background = col;
-  restart_matrix();
-}
-
-void KMatrixSaver::setForegroundColor(const QColor &col ) {
-  cfg.foreground = col;
-  restart_matrix();
-}
-
 void KMatrixSaver::setDensity(int den) {
   if( den>0 && den <=100 ) {
     cfg.density = den;
@@ -156,12 +139,6 @@ inline void KMatrixSaver::readSettings() {
   cfg.readSettings();
 }
 
-void KMatrixSaver::blank()
-{
-    QPainter p(this);
-    p.fillRect( 0, 0, width(), height(), black );
-}
-
 //---------------------------------------------------------------------
 /* restart matrix *
    this function is not a part of original xtarix code */
@@ -180,7 +157,7 @@ void KMatrixSaver::shutdown_matrix() {
     if( state->feeders!=NULL ) {
       free(state->feeders); state->feeders = NULL;
     }
-    free(state); state = NULL;
+    delete state; state = NULL;
   }
 }
 
@@ -211,9 +188,18 @@ void KMatrixSaver::shutdown_matrix() {
 
 /* load images */
 void KMatrixSaver::load_images () {
-  if (!cfg.mono && QPixmap::defaultDepth() > 1 )
+  if ( QPixmap::defaultDepth() > 1 )
     {
-      state->images = QPixmap( matrix_font );
+      //The XPM has alpha region for blank spots.. Get rid of them by blending
+      //With black once.
+      QImage img (matrix_font);
+      QPixmap solid ( img.width(), img.height() );
+      QPainter p( &solid );
+      p.fillRect( 0, 0, img.width(), img.height(), Qt::black );
+      p.drawImage( 0, 0, img );
+      p.end();
+
+      state->images = solid;
       state->image_width = state->images.width();
       state->image_height = state->images.height();
       state->nglyphs = state->image_height / CHAR_HEIGHT;
@@ -266,7 +252,7 @@ void KMatrixSaver::init_matrix () {
       state->insert_bottom_p = true;
     }
 
-  /* return state; */
+  setBackgroundColor(black);
 }
 
 void KMatrixSaver::insert_glyph (int glyph, int x, int y) {
@@ -446,7 +432,6 @@ void KMatrixSaver::draw_matrix () {
 
 }
 
-
 //--------------------------------------------------------------------
 // dialog to setup screen saver parameters
 //
@@ -518,7 +503,7 @@ KMatrixSetup::KMatrixSetup( QWidget *parent, const char *name )
   QRadioButton *rb;
   int i = 0;
   insertRbGrp = new QButtonGroup(2, Qt::Horizontal, this, "insertGroup");
-  insertRbGrp->setTitle(i18n("Insert from:"));
+  insertRbGrp->setTitle(i18n("Insert From"));
   QVBoxLayout *grpvbox = new QVBoxLayout(insertRbGrp, 10);
   QFontMetrics  metrics(insertRbGrp->font());
   grpvbox->addSpacing(metrics.height()/2+4);
@@ -555,14 +540,14 @@ KMatrixSetup::KMatrixSetup( QWidget *parent, const char *name )
 
   // -----------
   KButtonBox *bbox = new KButtonBox(this);
-  button = bbox->addButton(i18n("About"));
+  button = bbox->addButton(i18n("&About"));
   connect(button, SIGNAL(clicked()), SLOT(slotAbout()));
   bbox->addStretch(1);
 
-  button = bbox->addButton( i18n("OK"));
+  button = bbox->addButton( i18n("&OK"));
   connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
 
-  button = bbox->addButton(i18n("Cancel"));
+  button = bbox->addButton(i18n("&Cancel"));
   connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
   bbox->layout();
   tl->addWidget(bbox);
@@ -580,26 +565,6 @@ inline void KMatrixSetup::readSettings() {
   cfg.readSettings();
 }
 
-void KMatrixSetup::slotBackgrColor() {
-  if ( KColorDialog::getColor(cfg.background) == QDialog::Accepted ) {
-    saver->setBackgroundColor(cfg.background);
-    QColorGroup colgrp(black, cfg.background, cfg.background.light(),
-		       cfg.background.dark(), cfg.background.dark(120),
-		       black, white);
-    backgrPush->setPalette( QPalette( colgrp, colgrp, colgrp ) );
-  }
-}
-
-void KMatrixSetup::slotForegrColor() {
-  if ( KColorDialog::getColor(cfg.foreground) == QDialog::Accepted ) {
-    saver->setForegroundColor(cfg.foreground);
-    QColorGroup colgrp(black, cfg.foreground, cfg.foreground.light(),
-		       cfg.foreground.dark(), cfg.foreground.dark(120),
-		       black, white);
-    foregrPush->setPalette( QPalette( colgrp, colgrp, colgrp ) );
-  }
-}
-
 void KMatrixSetup::slotDensity(int val) {
   setDensity(val);
   // update edit control
@@ -655,9 +620,9 @@ void KMatrixSetup::slotOkPressed() {
 void KMatrixSetup::slotAbout() {
   KMessageBox::about(0,
 		       i18n("KMatrix\n\n"
-"based on xmatrix\n"
-"Copyright (C) 1999 by Jamie Zawinski <jwz@jwz.org>\n"
-"Ported to kscreensaver by Dmitry DELTA Malykhanov\n"
+"Based on xmatrix\n"
+"Copyright (c) 1999 by Jamie Zawinski <jwz@jwz.org>\n"
+"Ported to KScreenSaver by Dmitry DELTA Malykhanov\n"
 "<d.malykhanov@iname.com>\n"
 "Ported to KDE 2.0 by Thorsten Westheider\n"
 "<thorsten.westheider@teleos-web.de>"),
