@@ -58,7 +58,7 @@
 extern "C"
 {
     const char *kss_applicationName = "kscience.kss";
-    const char *kss_description = I18N_NOOP( "Science Screensaver" );
+    const char *kss_description = I18N_NOOP( "Science Screen Saver" );
     const char *kss_version = "2.2.0";
 
     KScreenSaver *kss_create( WId id )
@@ -911,7 +911,7 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name ) :
 	ltm->addSpacing( 5 );
 		
 	// hide background
-	cbox = checkHideBG = new QCheckBox( i18n("Hide Background"), this );
+	cbox = checkHideBG = new QCheckBox( i18n("Hide background"), this );
 	cbox->setChecked( hideBG[mode] );
 	cbox->adjustSize();
 	cbox->setMinimumSize( cbox->sizeHint() );
@@ -1001,14 +1001,14 @@ KScienceSetup::KScienceSetup(  QWidget *parent, const char *name ) :
 
 	// buttons
 	KButtonBox *bbox = new KButtonBox( this );
-	button = bbox->addButton( i18n("About") );
+	button = bbox->addButton( i18n("&About") );
 	connect( button, SIGNAL( clicked() ), SLOT( slotAbout() ) );
 	bbox->addStretch( 1 );
 
-	button = bbox->addButton( i18n("OK") );
+	button = bbox->addButton( i18n("&OK") );
 	connect( button, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
 
-	button = bbox->addButton( i18n("Cancel") );
+	button = bbox->addButton( i18n("&Cancel") );
 	connect( button, SIGNAL( clicked() ), SLOT( reject() ) );
 	bbox->layout();
 	lt->addWidget( bbox );
@@ -1181,7 +1181,7 @@ void KScienceSetup::slotOkPressed()
 
 void KScienceSetup::slotAbout()
 {
-	QString about = i18n("Science Version 0.26.5\n\nwritten by Rene Beutler (1998)\nrbeutler@g26.ethz.ch");
+	QString about = i18n("Science Version 0.26.5\n\nWritten by Rene Beutler (1998)\nrbeutler@g26.ethz.ch");
 	KMessageBox::about(this,
 	                      about);
 }
