@@ -10,7 +10,7 @@
 #include <kapplication.h>
 #include <klocale.h>
 #include <kconfig.h>
-#include <kcolordlg.h>
+#include <kcolordialog.h>
 #include <kbuttonbox.h>
 #include <kcolorbutton.h>
 #include <kglobal.h>
@@ -25,6 +25,7 @@
 #include <qspinbox.h>
 #include <kstandarddirs.h>
 #include <math.h>
+#include <kmessagebox.h>
 #ifndef GLU_NURBS_TEXTURE_COORD
 #define GLU_NURBS_TEXTURE_COORD            100168
 #endif
@@ -62,6 +63,7 @@ KWaveSetup::KWaveSetup( QWidget *parent, const char *name )
 
 	connect( PushButton1, SIGNAL( clicked() ), SLOT( slotOkPressed() ) );
 	connect( PushButton2, SIGNAL( clicked() ), SLOT( reject() ) );
+	connect( PushButton3, SIGNAL( clicked() ), SLOT( aboutPressed() ) );
 	connect(  SpinBox1, SIGNAL( valueChanged(int)), saver, SLOT( updateSize(int)));
 	connect( RadioButton1, SIGNAL( toggled(bool)), saver, SLOT( doStars(bool)));
 
@@ -91,7 +93,8 @@ void KWaveSetup::slotOkPressed()
 
 void KWaveSetup::aboutPressed()
 {
-
+    KMessageBox::about(this,
+        i18n("<h3>Bitmap Flag Screen Saver</h3>\n<p>Waving Flag Screen Saver for KDE</p>\nCopyright (c)  Ian Reinhart Geiser 2001"));
 }
 //-----------------------------------------------------------------------------
 
@@ -272,7 +275,6 @@ void Wave::paintGL ()
         // Restore the modelview matrix
         glPopMatrix();
 
-	swapBuffers ();
 	glFlush();
 }
 
