@@ -59,17 +59,19 @@ bool g_inited = false;
 extern "C"
 {
     const char *kss_applicationName = "kpartsaver";
-    const char *kss_description = I18N_NOOP( "KPart Screensaver" );
+    const char *kss_description = I18N_NOOP( "KPart Screen Saver" );
     const char *kss_version = "1.0";
 
     KScreenSaver *kss_create( WId d )
     {
+        KGlobal::locale()->insertCatalogue("kpartsaver");
         return new KPartSaver( d );
     }
 
     QDialog *kss_setup()
     {
         kdDebug() << "kss_setup" << endl;
+        KGlobal::locale()->insertCatalogue("kpartsaver");
         return new SaverConfig;
     }
 }
@@ -85,7 +87,7 @@ void exitHandler( int )
 
 
 KPartSaver::KPartSaver( WId id )
-    : KScreenSaver( id ), m_timer(), m_part(0), m_current(-1), m_back(0)
+    : KScreenSaver( id ), m_timer(), m_part(0), m_current(-1), m_back(0), m_factory(0)
 {
     // install signal handlers to make sure that nspluginviewer is shutdown correctly
     // move this into the nspluginviewer kpart code
@@ -119,7 +121,7 @@ KPartSaver::KPartSaver( WId id )
     if( m_files.count()==0 ) {
 
         // create background widget
-        m_back = new QLabel( i18n("The screensaver isn't configured yet"), this );
+        m_back = new QLabel( i18n("The screen saver is not configured yet."), this );
 
         m_back->setAlignment( AlignCenter );
         embed( m_back );
@@ -146,7 +148,7 @@ KPartSaver::KPartSaver( WId id )
 
 KPartSaver::~KPartSaver()
 {
-    g_savers.remove( this );
+    g_savers.take( g_savers.findRef( this ));
     closeURL();
 }
 
@@ -346,7 +348,7 @@ void SaverConfig::apply()
 void SaverConfig::add()
 {
     KURL::List files = KFileDialog::getOpenURLs( QString::null, QString::null,
-                                                 this, i18n("Select media files") );
+                                                 this, i18n("Select Media Files") );
     for( unsigned int n=0; n<files.count(); n++ )
         m_files->insertItem( files[n].prettyURL(), -1 );
 }
