@@ -747,7 +747,7 @@ void kPipesSaver::readSettings()
 
 kPipesSetup::kPipesSetup( QWidget *parent, const char *name )
   : KDialogBase( parent, name, true, i18n("Setup Pipes Screen Saver"), Ok|Cancel|User1,
-		Ok, false, i18n("About") )
+		Ok, false, i18n("&About") )
 {
   readSettings();
 
@@ -759,7 +759,7 @@ kPipesSetup::kPipesSetup( QWidget *parent, const char *name )
   QLabel *label;
   QSlider *slider;
 
-  label = new QLabel( i18n("Number of Pipes"), page );
+  label = new QLabel( i18n("Number of pipes:"), page );
   vb->addWidget( label );
 
   slider = new QSlider(2, MAXPIPES, 1, pipes, QSlider::Horizontal, page );
