@@ -139,6 +139,6 @@ protected slots:
 	void slotMaximize(int button);
 };
 
-}; // namespace
+} // namespace
 
 #endif
